import { ComponentClass, ComponentType } from 'react';
import { LoadingState, SeriesData } from './data';
import { TimeRange } from './time';
import { ScopedVars, DataQueryRequest, DataQueryError, LegacyResponseData } from './datasource';
import { PluginMeta, GrafanaPlugin } from './plugin';
export declare type InterpolateFunction = (value: string, scopedVars?: ScopedVars, format?: string | Function) => string;
export interface PanelPluginMeta extends PluginMeta {
    skipDataQuery?: boolean;
    hideFromList?: boolean;
    sort: number;
}
export interface PanelData {
    state: LoadingState;
    series: SeriesData[];
    request?: DataQueryRequest;
    error?: DataQueryError;
    legacy?: LegacyResponseData[];
}
export interface PanelProps<T = any> {
    id: number;
    data: PanelData;
    timeRange: TimeRange;
    options: T;
    onOptionsChange: (options: T) => void;
    renderCounter: number;
    width: number;
    height: number;
    replaceVariables: InterpolateFunction;
}
export interface PanelEditorProps<T = any> {
    options: T;
    onOptionsChange: (options: T) => void;
}
export interface PanelModel<TOptions = any> {
    id: number;
    options: TOptions;
    pluginVersion?: string;
}
/**
 * Called when a panel is first loaded with current panel model
 */
export declare type PanelMigrationHandler<TOptions = any> = (panel: PanelModel<TOptions>) => Partial<TOptions>;
/**
 * Called before a panel is initalized
 */
export declare type PanelTypeChangedHandler<TOptions = any> = (options: Partial<TOptions>, prevPluginId: string, prevOptions: any) => Partial<TOptions>;
export declare class PanelPlugin<TOptions = any> extends GrafanaPlugin<PanelPluginMeta> {
    panel: ComponentType<PanelProps<TOptions>>;
    editor?: ComponentClass<PanelEditorProps<TOptions>>;
    defaults?: TOptions;
    onPanelMigration?: PanelMigrationHandler<TOptions>;
    onPanelTypeChanged?: PanelTypeChangedHandler<TOptions>;
    /**
     * Legacy angular ctrl.  If this exists it will be used instead of the panel
     */
    angularPanelCtrl?: any;
    constructor(panel: ComponentType<PanelProps<TOptions>>);
    setEditor(editor: ComponentClass<PanelEditorProps<TOptions>>): this;
    setDefaults(defaults: TOptions): this;
    /**
     * This function is called before the panel first loads if
     * the current version is different than the version that was saved.
     *
     * This is a good place to support any changes to the options model
     */
    setMigrationHandler(handler: PanelMigrationHandler): this;
    /**
     * This function is called when the visualization was changed.  This
     * passes in the options that were used in the previous visualization
     */
    setPanelChangeHandler(handler: PanelTypeChangedHandler): this;
}
export interface PanelSize {
    width: number;
    height: number;
}
export interface PanelMenuItem {
    type?: 'submenu' | 'divider';
    text?: string;
    iconClassName?: string;
    onClick?: () => void;
    shortcut?: string;
    subMenu?: PanelMenuItem[];
}
export declare enum MappingType {
    ValueToText = 1,
    RangeToText = 2
}
interface BaseMap {
    id: number;
    operator: string;
    text: string;
    type: MappingType;
}
export declare type ValueMapping = ValueMap | RangeMap;
export interface ValueMap extends BaseMap {
    value: string;
}
export interface RangeMap extends BaseMap {
    from: string;
    to: string;
}
export declare enum VizOrientation {
    Auto = "auto",
    Vertical = "vertical",
    Horizontal = "horizontal"
}
export {};
