import { ComponentClass } from 'react';
export declare enum PluginState {
    alpha = "alpha",
    beta = "beta"
}
export declare enum PluginType {
    panel = "panel",
    datasource = "datasource",
    app = "app"
}
export interface PluginMeta {
    id: string;
    name: string;
    type: PluginType;
    info: PluginMetaInfo;
    includes?: PluginInclude[];
    state?: PluginState;
    module: string;
    baseUrl: string;
    dependencies?: PluginDependencies;
    jsonData?: {
        [str: string]: any;
    };
    secureJsonData?: {
        [str: string]: any;
    };
    enabled?: boolean;
    defaultNavUrl?: string;
    hasUpdate?: boolean;
    latestVersion?: string;
    pinned?: boolean;
}
interface PluginDependencyInfo {
    id: string;
    name: string;
    version: string;
    type: PluginType;
}
export interface PluginDependencies {
    grafanaVersion: string;
    plugins: PluginDependencyInfo[];
}
export declare enum PluginIncludeType {
    dashboard = "dashboard",
    page = "page",
    panel = "panel",
    datasource = "datasource"
}
export interface PluginInclude {
    type: PluginIncludeType;
    name: string;
    path?: string;
    icon?: string;
    role?: string;
    addToNav?: boolean;
    component?: string;
}
interface PluginMetaInfoLink {
    name: string;
    url: string;
}
export interface PluginMetaInfo {
    author: {
        name: string;
        url?: string;
    };
    description: string;
    links: PluginMetaInfoLink[];
    logos: {
        large: string;
        small: string;
    };
    screenshots: any[];
    updated: string;
    version: string;
}
export interface PluginConfigPageProps<T extends GrafanaPlugin> {
    plugin: T;
    query: {
        [s: string]: any;
    };
}
export interface PluginConfigPage<T extends GrafanaPlugin> {
    title: string;
    icon?: string;
    id: string;
    body: ComponentClass<PluginConfigPageProps<T>>;
}
export declare class GrafanaPlugin<T extends PluginMeta = PluginMeta> {
    meta?: T;
    angularConfigCtrl?: any;
    configPages?: Array<PluginConfigPage<GrafanaPlugin>>;
    addConfigPage(tab: PluginConfigPage<GrafanaPlugin>): this;
}
export {};
